TODO List
=========

#. Rationalize the different readers defined in pymatgen and abipy.
   Try to integrate some method of abipy.core.Structure in pymatgen.core.Structure.
   See the hack used in iotools.__init__.py

#. split long lines in the abinit input (e.g. typat 1 1 1 2 --> typat 3*1 2)

#. Better support for PBS
